AndroidCredentialProvider class final
Loads Google Play and Android signing credentials from environment values.
Constructors
-
AndroidCredentialProvider({required Map<
String, String> environment}) -
Creates a credential provider over
environment.const - AndroidCredentialProvider.system()
-
Creates a provider using the current process environment.
factory
Properties
-
environment
→ Map<
String, String> -
Environment containing credential values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
googlePlayCredentials(
) → Future< GooglePlayCredentials> - Loads the service-account JSON.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signingCredentials(
) → Future< AndroidSigningCredentials> - Loads one upload-keystore source and its passwords.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited