AndroidProject class final

Android project metadata used by Google Play delivery.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectVersion(String appRoot) Future<String?>
Detects one stable version name from conventional project files.
resolvePackageName(String appRoot, AndroidConfig config, {String? flavor}) Future<String>
Resolves the application ID used by Google Play.