AndroidReleaseCandidate class final

Creates and records exact Google Play release candidates.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(AndroidReleaseCandidateOptions options) Future<ReleaseCandidateReceiptDto>
Builds, signs, uploads, and records an exact internal-testing release candidate. Creates or reuses the exact release candidate described by options.