AndroidReleaseCandidateDependencies class final
Release-candidate build operations injectable for deterministic tests.
Constructors
-
AndroidReleaseCandidateDependencies({Future<
String> resolvePackage(String appRoot, AndroidConfig config, {String? flavor}) = AndroidProject.resolvePackageName, Future<bool> runBeforeBuild({required String workingDirectory}) = RepositoryHooks.beforeBuild, Future<AndroidSigningSession> installSigning(AndroidSigningCredentials credentials) = AndroidSigningSession.install, Future<String> buildAab({required String aabOutputPath, required String buildNumber, required String command, required AndroidSigningCredentials credentials, String? flavor, required String projectRoot, required AndroidSigningSession signing, required String version}) = AndroidBuild.run, DateTime currentTime() = _currentTime}) -
Creates Android release candidate dependencies.
const
Properties
-
buildAab
→ Future<
String> Function({required String aabOutputPath, required String buildNumber, required String command, required AndroidSigningCredentials credentials, String? flavor, required String projectRoot, required AndroidSigningSession signing, required String version}) -
Signed AAB builder.
final
- currentTime → DateTime Function()
-
Receipt clock.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
installSigning
→ Future<
AndroidSigningSession> Function(AndroidSigningCredentials credentials) -
Temporary upload-key installer.
final
-
resolvePackage
→ Future<
String> Function(String appRoot, AndroidConfig config, {String? flavor}) -
Android application-ID resolver.
final
-
runBeforeBuild
→ Future<
bool> Function({required String workingDirectory}) -
Repository-owned release candidate preparation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited