AndroidShipReleaseResultDto class final

Stable machine-readable evidence produced after shipping an Android release.

Constructors

AndroidShipReleaseResultDto({required String version, required String tag, required int versionCode, required String testingTrack, required String githubReleaseUrl, List<String> testingTracks = const <String>[], List<String> shippedTracks = const <String>[], String? productionTrack})
Creates an Android ship result.

Properties

artifactId String
no setter
buildNumber String
no setter
githubReleaseUrl String
GitHub release URL.
final
hashCode int
The hash code for this object.
no setterinherited
platform ReleasePlatform
no setter
productionTrack String?
Production track updated by this promotion, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippedTracks List<String>
Every track updated during the ship phase.
final
tag String
Git tag created for this Android release.
final
testingTrack String
Testing track that contained the release candidate.
final
testingTracks List<String>
Every testing track that contained the release candidate.
final
version String
Promoted marketing version.
final
versionCode int
Exact Google Play version code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes the Android ship result.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited