GooglePlayBundle class final

One uploaded Android App Bundle.

Constructors

GooglePlayBundle({required int versionCode, required String sha256})
Creates bundle evidence.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
SHA-256 digest returned by Google Play.
final
versionCode int
Manifest version code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited