GooglePlayRelease class final

One release configured on a Google Play track.

Constructors

GooglePlayRelease({required GooglePlayReleaseStatus status, required List<int> versionCodes, String? name, Map<String, String> releaseNotes = const <String, String>{}})
Creates a track release.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Optional release name.
final
releaseNotes Map<String, String>
Localized "What's new" text keyed by BCP-47 language.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GooglePlayReleaseStatus
Google Play release state.
final
versionCodes List<int>
Version codes currently included in the release.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited