GooglePlayReleaseStatus enum
State of one release returned by Google Play.
Values
- unspecified → const GooglePlayReleaseStatus
-
Google Play did not assign a meaningful state.
const GooglePlayReleaseStatus('statusUnspecified') - draft → const GooglePlayReleaseStatus
-
The release exists but is not served.
const GooglePlayReleaseStatus('draft') - inProgress → const GooglePlayReleaseStatus
-
The release is served to a configured fraction of eligible users.
const GooglePlayReleaseStatus('inProgress') - halted → const GooglePlayReleaseStatus
-
The release is no longer served to new users.
const GooglePlayReleaseStatus('halted') - completed → const GooglePlayReleaseStatus
-
The release is fully rolled out on its track.
const GooglePlayReleaseStatus('completed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Stable Android Publisher API value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
Object? value) → GooglePlayReleaseStatus - Parses a release state at the Google Play response boundary.
Constants
-
values
→ const List<
GooglePlayReleaseStatus> - A constant List of the values in this enum, in order of their declaration.