GooglePlayTrack class final
Current desired state for a Google Play track.
Constructors
-
GooglePlayTrack({required String name, List<
GooglePlayRelease> releases = const <GooglePlayRelease>[]}) -
Creates track state.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Track identifier.
final
-
releases
→ List<
GooglePlayRelease> -
Active or desired releases.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
containsCompletedVersionCode(
int versionCode) → bool -
Whether
versionCodeis fully rolled out on this track. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseForVersionCode(
int versionCode) → GooglePlayRelease? -
Release containing
versionCode, if Google Play currently returns one. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited