ApiResourceDto<T> class abstract

A typed JSON:API resource returned by App Store Connect.

Available extensions
Annotations
  • @Freezed.new(genericArgumentFactories: true)

Constructors

ApiResourceDto({required String type, required String id, required T attributes})
Creates an App Store Connect resource.
const
factory
ApiResourceDto.fromJson(Map<String, Object?> json, T fromJsonT(Object?))
Decodes an App Store Connect resource from JSON.
factory

Properties

attributes → T
no setterinherited
copyWith → $ApiResourceDtoCopyWith<T, ApiResourceDto<T>>
Create a copy of ApiResourceDto with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ApiResourceDto<T> value)) → TResult

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApiResourceDto<T> value)?) → TResult?

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApiResourceDto<T> value)?, {required TResult orElse()}) → TResult

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String type, String id, T attributes)?, {required TResult orElse()}) → TResult

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T)) Map<String, dynamic>
Serializes this ApiResourceDto to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String type, String id, T attributes)) → TResult

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String type, String id, T attributes)?) → TResult?

Available on ApiResourceDto<T>, provided by the ApiResourceDtoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited