AppAttributesDto class abstract
App attributes returned by App Store Connect.
- Available extensions
- Annotations
-
- @freezed
Constructors
- AppAttributesDto({required String name, required String bundleId, required String sku, required String primaryLocale})
-
Creates app attributes.
constfactory
-
AppAttributesDto.fromJson(Map<
String, Object?> json) -
Decodes app attributes from JSON.
factory
Properties
- bundleId → String
-
no setterinherited
-
copyWith
→ $AppAttributesDtoCopyWith<
AppAttributesDto> -
Create a copy of AppAttributesDto
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setterinherited
- primaryLocale → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sku → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AppAttributesDto value)) → TResult -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AppAttributesDto value)?) → TResult? -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AppAttributesDto value)?, {required TResult orElse()}) → TResult -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String name, String bundleId, String sku, String primaryLocale)?, {required TResult orElse()}) → TResult -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AppAttributesDto to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String name, String bundleId, String sku, String primaryLocale)) → TResult -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String name, String bundleId, String sku, String primaryLocale)?) → TResult? -
Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited