AppAttributesDtoPatterns extension

Adds pattern-matching-related methods to AppAttributesDto.

on

Methods

map<TResult extends Object?>(TResult $default(_AppAttributesDto value)) → TResult

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AppAttributesDto value)?) → TResult?

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AppAttributesDto value)?, {required TResult orElse()}) → TResult

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, String bundleId, String sku, String primaryLocale)?, {required TResult orElse()}) → TResult

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String name, String bundleId, String sku, String primaryLocale)) → TResult

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, String bundleId, String sku, String primaryLocale)?) → TResult?

Available on AppAttributesDto, provided by the AppAttributesDtoPatterns extension

A variant of when that fallback to returning null