App Store Connect operations required by SMF delivery workflows.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBuildToGroups(
{required String appId, required String buildId, required List< String> names, required bool isInternal}) → Future<void> - Adds an exact build to the named internal or external TestFlight groups.
-
appStoreVersionBuildId(
String appStoreVersionId) → Future< String?> - Returns the build currently attached to an App Store version.
-
attachBuildToVersion(
{required String appStoreVersionId, required String buildId}) → Future< void> - Attaches an exact build to an App Store version.
-
buildsForVersion(
{required String appId, required String version}) → Future< List< ApiResourceDto< >BuildAttributesDto> > - Lists builds uploaded for one app marketing version.
-
close(
) → void - Releases authentication and transport resources.
-
createAppStoreProfile(
{required String name, required String bundleIdId, required String certificateId}) → Future< AppleProvisioningProfileDto> - Creates an App Store profile for one bundle identifier and certificate.
-
findApp(
String bundleId) → Future< ApiResourceDto< AppAttributesDto> > -
Finds the app whose bundle identifier exactly matches
bundleId. -
findOrCreateAppStoreVersion(
{required String appId, required String version, required bool shouldReleaseAutomatically}) → Future< ApiResourceDto< AppStoreVersionAttributesDto> > - Finds or creates the editable App Store version for a marketing version.
-
listAppStoreProfiles(
) → Future< List< AppleProvisioningProfileDto> > - Lists App Store provisioning profiles registered with the developer team.
-
listIosBundleIds(
) → Future< List< AppleBundleIdentifierDto> > - Lists iOS bundle identifiers registered with the developer team.
-
listSigningCertificates(
) → Future< List< AppleSigningCertificateDto> > - Lists signing certificates registered with the developer team.
-
nextBuildNumber(
{required String appId, required String version}) → Future< String> - Returns the next unused build number for one app marketing version.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAppStoreReleaseNotes(
{required String appStoreVersionId, required String locale, required String whatsNew}) → Future< void> - Creates or updates localized App Store "What's New" text.
-
setBetaBuildLocalization(
{required String buildId, required String locale, required String whatsNew}) → Future< void> - Creates or updates localized TestFlight "What to Test" text.
-
submitBuildForBetaReview(
String buildId) → Future< String> - Submits an exact build for TestFlight beta review.
-
submitVersionForReview(
{required String appId, required String appStoreVersionId}) → Future< String> - Creates or reuses the review submission for an App Store version.
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForBuild(
{required String appId, required String version, required String buildNumber, required int timeoutMinutes, Duration interval = const Duration(seconds: 30)}) → Future< ApiResourceDto< BuildAttributesDto> > - Waits for an exact uploaded build to finish App Store processing.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited