findApp abstract method
Finds the app whose bundle identifier exactly matches bundleId.
Implementation
Future<ApiResourceDto<AppAttributesDto>> findApp(String bundleId);
Finds the app whose bundle identifier exactly matches bundleId.
Future<ApiResourceDto<AppAttributesDto>> findApp(String bundleId);