AppStoreReleaseType enum

Release policy configured for an App Store version.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

manual → const AppStoreReleaseType

The developer manually releases the version after approval.

const AppStoreReleaseType('MANUAL')
afterApproval → const AppStoreReleaseType

Apple releases the version automatically after approval.

const AppStoreReleaseType('AFTER_APPROVAL')
scheduled → const AppStoreReleaseType

Apple releases the version at a configured date.

const AppStoreReleaseType('SCHEDULED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Stable App Store Connect API value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppStoreReleaseType>
A constant List of the values in this enum, in order of their declaration.