AppStoreVersionAttributesDto class abstract

App Store version attributes returned by App Store Connect.

Available extensions
Annotations
  • @freezed

Constructors

AppStoreVersionAttributesDto({required ApplePlatform platform, required String versionString, required AppVersionState appVersionState, required AppStoreReleaseType releaseType})
Creates App Store version attributes.
const
factory
AppStoreVersionAttributesDto.fromJson(Map<String, Object?> json)
Decodes App Store version attributes from JSON.
factory

Properties

appVersionState AppVersionState
no setterinherited
copyWith → $AppStoreVersionAttributesDtoCopyWith<AppStoreVersionAttributesDto>
Create a copy of AppStoreVersionAttributesDto with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
platform ApplePlatform
no setterinherited
releaseType AppStoreReleaseType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionString String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AppStoreVersionAttributesDto value)) → TResult

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AppStoreVersionAttributesDto value)?) → TResult?

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AppStoreVersionAttributesDto value)?, {required TResult orElse()}) → TResult

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ApplePlatform platform, String versionString, AppVersionState appVersionState, AppStoreReleaseType releaseType)?, {required TResult orElse()}) → TResult

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AppStoreVersionAttributesDto to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ApplePlatform platform, String versionString, AppVersionState appVersionState, AppStoreReleaseType releaseType)) → TResult

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ApplePlatform platform, String versionString, AppVersionState appVersionState, AppStoreReleaseType releaseType)?) → TResult?

Available on AppStoreVersionAttributesDto, provided by the AppStoreVersionAttributesDtoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited