AppVersionState enum

Current lifecycle state of an App Store version.

Inheritance
Available extensions

Values

accepted → const AppVersionState

Apple accepted the version.

developerRejected → const AppVersionState

The developer removed the version from review.

inReview → const AppVersionState

App Review is actively reviewing the version.

invalidBinary → const AppVersionState

Apple rejected the uploaded binary.

metadataRejected → const AppVersionState

App Review rejected the version metadata.

pendingAppleRelease → const AppVersionState

Apple is waiting to publish an approved version.

pendingDeveloperRelease → const AppVersionState

The developer must manually release the approved version.

prepareForSubmission → const AppVersionState

The version can still be configured before submission.

processingForDistribution → const AppVersionState

Apple is processing the approved version for distribution.

readyForDistribution → const AppVersionState

The version is available for distribution.

readyForReview → const AppVersionState

The version has all required submission items and can enter review.

rejected → const AppVersionState

App Review rejected the version.

replacedWithNewVersion → const AppVersionState

A newer App Store version replaced this version.

waitingForExportCompliance → const AppVersionState

Apple requires export-compliance information.

waitingForReview → const AppVersionState

The isSubmitted version is waiting for App Review.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isEditable bool
Whether metadata and build relationships can still be changed.
no setter
isRejected bool
Whether this state requires a human correction before SMF can continue.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppVersionState>
A constant List of the values in this enum, in order of their declaration.