AppleBundleIdentifierDto class abstract

An App ID registered with the Apple developer team.

Available extensions
Annotations
  • @freezed

Constructors

AppleBundleIdentifierDto({required String id, required String identifier, required String platform})
Creates an Apple bundle-identifier resource.
const
factory

Properties

copyWith → $AppleBundleIdentifierDtoCopyWith<AppleBundleIdentifierDto>
Create a copy of AppleBundleIdentifierDto with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
identifier String
no setterinherited
platform String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AppleBundleIdentifierDto value)) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AppleBundleIdentifierDto value)?) → TResult?

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AppleBundleIdentifierDto value)?, {required TResult orElse()}) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String identifier, String platform)?, {required TResult orElse()}) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String identifier, String platform)) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String identifier, String platform)?) → TResult?

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited