AppleBundleIdentifierDtoPatterns extension

Adds pattern-matching-related methods to AppleBundleIdentifierDto.

on

Methods

map<TResult extends Object?>(TResult $default(_AppleBundleIdentifierDto value)) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AppleBundleIdentifierDto value)?) → TResult?

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AppleBundleIdentifierDto value)?, {required TResult orElse()}) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String identifier, String platform)?, {required TResult orElse()}) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, String identifier, String platform)) → TResult

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String identifier, String platform)?) → TResult?

Available on AppleBundleIdentifierDto, provided by the AppleBundleIdentifierDtoPatterns extension

A variant of when that fallback to returning null