AppleCredentialProvider class final

Constructors

AppleCredentialProvider({required Map<String, String> environment})
const
AppleCredentialProvider.system()
factory

Properties

environment Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appleCredentials() Future<AppleCredentials>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signingCredentials() Future<AppleSigningCredentials>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited