AppleCredentials class final

App Store Connect API credentials.

This deliberately does not use generated value semantics so private key material is never included in a generated toString.

Constructors

AppleCredentials({required String keyId, required String issuerId, required String privateKey})
Creates App Store Connect API credentials.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
issuerId String
App Store Connect issuer identifier.
final
keyId String
App Store Connect API key identifier.
final
privateKey String
Raw private key contents. Callers must never log or persist this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited