AppleInstalledProfile class final

A provisioning profile installed for one signed bundle.

Constructors

AppleInstalledProfile({required String bundleId, required String uuid, required String name, required String teamId, required String installedPath})
Creates installed-profile metadata.
const

Properties

bundleId → String
Bundle identifier authorized by the profile.
final
hashCode → int
The hash code for this object.
no setterinherited
installedPath → String
Temporary installed profile path.
final
name → String
Provisioning-profile name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId → String
Apple developer team identifier.
final
uuid → String
Provisioning-profile UUID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited