AppleProject class final

Xcode project metadata used by Apple delivery.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectVersion(String appRoot) Future<String?>
Detects one stable marketing version from conventional project files.
resolveBundleId(String appRoot, IosConfig config, {String? flavor, ProcessRunner processRunner = const SystemProcessRunner(), bool? isMacOS}) Future<String>
Resolves the main application bundle identifier.
resolveSigningBundleIds(String appRoot, {required String mainBundleId, String? flavor, ProcessRunner processRunner = const SystemProcessRunner(), bool? isMacOS}) Future<Set<String>>
Resolves every signed app or extension bundle ID in the Release scheme.