AppleProvisioning class final

Resolves exact App Store profiles for signed application targets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolve({required AppleSigningCredentials credentials, required Set<String> bundleIds, required AppStoreConnectApi client, ProcessRunner processRunner = const SystemProcessRunner(), Directory? temporaryRoot, DateTime currentTime()?}) Future<AppleResolvedSigningAssets>
Finds or creates profiles through Apple's supported provisioning API.