AppleProvisioningProfileDtoPatterns extension

Adds pattern-matching-related methods to AppleProvisioningProfileDto.

on

Methods

map<TResult extends Object?>(TResult $default(_AppleProvisioningProfileDto value)) → TResult

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AppleProvisioningProfileDto value)?) → TResult?

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AppleProvisioningProfileDto value)?, {required TResult orElse()}) → TResult

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List<String> certificateIds)?, {required TResult orElse()}) → TResult

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List<String> certificateIds)) → TResult

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List<String> certificateIds)?) → TResult?

Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension

A variant of when that fallback to returning null