AppleRelease class final

Promotes exact tested App Store Connect release candidates without rebuilding.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

promote(ApplePromotionOptions options) Future<AppleShipReleaseResultDto>
Verifies and promotes the exact release candidate described by options.