shouldCommitReceipt property
Whether release candidate evidence should be committed to the release branch.
Implementation
final bool shouldCommitReceipt;
Whether release candidate evidence should be committed to the release branch.
final bool shouldCommitReceipt;