AppleSigning class final

Installs and validates temporary Apple signing assets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

install(AppleResolvedSigningAssets assets, String bundleId, {ProcessRunner processRunner = const SystemProcessRunner(), bool? isMacOS, String? homeDirectory, Directory? temporaryRoot}) Future<AppleSigningSession>
Installs signing assets for one bundle and its extensions.