AppleSigningCredentials class final

Apple distribution signing material.

This deliberately does not use generated value semantics so signing secrets are never included in a generated toString.

Constructors

AppleSigningCredentials({required String certificateBase64, required String certificatePassword})
Creates signing credentials.
const

Properties

certificateBase64 String
Base64-encoded distribution certificate and private key.
final
certificatePassword String
Password protecting the distribution certificate.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited