BuildAttributesDto class abstract
Build attributes returned by App Store Connect.
- Available extensions
- Annotations
-
- @freezed
Constructors
- BuildAttributesDto({required String version, required BuildProcessingState processingState, String? uploadedDate, @JsonKey.new(name: 'expired') @Default.new(false) bool isExpired, @JsonKey.new(name: 'usesNonExemptEncryption') bool? doesUseNonExemptEncryption})
-
Creates build attributes.
constfactory
-
BuildAttributesDto.fromJson(Map<
String, Object?> json) -
Decodes build attributes from JSON.
factory
Properties
-
copyWith
→ $BuildAttributesDtoCopyWith<
BuildAttributesDto> -
Create a copy of BuildAttributesDto
with the given fields replaced by the non-null parameter values.
no setterinherited
- doesUseNonExemptEncryption → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpired → bool
-
no setterinherited
- processingState → BuildProcessingState
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uploadedDate → String?
-
no setterinherited
- version → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BuildAttributesDto value)) → TResult -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BuildAttributesDto value)?) → TResult? -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BuildAttributesDto value)?, {required TResult orElse()}) → TResult -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String version, BuildProcessingState processingState, String? uploadedDate, bool isExpired, bool? doesUseNonExemptEncryption)?, {required TResult orElse()}) → TResult -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BuildAttributesDto to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String version, BuildProcessingState processingState, String? uploadedDate, bool isExpired, bool? doesUseNonExemptEncryption)) → TResult -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String version, BuildProcessingState processingState, String? uploadedDate, bool isExpired, bool? doesUseNonExemptEncryption)?) → TResult? -
Available on BuildAttributesDto, provided by the BuildAttributesDtoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited