BuildProcessingState enum

Processing state returned for an uploaded Apple build.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

processing → const BuildProcessingState

Apple is still processing the uploaded build.

const BuildProcessingState('PROCESSING')
failed → const BuildProcessingState

Processing failed before the build became usable.

const BuildProcessingState('FAILED')
invalid → const BuildProcessingState

Apple finished processing but rejected the build as invalid.

const BuildProcessingState('INVALID')
valid → const BuildProcessingState

The build finished processing and can be distributed.

const BuildProcessingState('VALID')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Stable App Store Connect API value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BuildProcessingState>
A constant List of the values in this enum, in order of their declaration.