PrereleaseVersionAttributesDto class abstract

Prerelease-version attributes returned by App Store Connect.

Available extensions
Annotations
  • @freezed

Constructors

PrereleaseVersionAttributesDto({required String version, required ApplePlatform platform})
Creates prerelease-version attributes.
const
factory
PrereleaseVersionAttributesDto.fromJson(Map<String, Object?> json)
Decodes prerelease-version attributes from JSON.
factory

Properties

copyWith → $PrereleaseVersionAttributesDtoCopyWith<PrereleaseVersionAttributesDto>
Create a copy of PrereleaseVersionAttributesDto with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
platform ApplePlatform
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PrereleaseVersionAttributesDto value)) → TResult

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PrereleaseVersionAttributesDto value)?) → TResult?

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PrereleaseVersionAttributesDto value)?, {required TResult orElse()}) → TResult

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String version, ApplePlatform platform)?, {required TResult orElse()}) → TResult

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PrereleaseVersionAttributesDto to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String version, ApplePlatform platform)) → TResult

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String version, ApplePlatform platform)?) → TResult?

Available on PrereleaseVersionAttributesDto, provided by the PrereleaseVersionAttributesDtoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited