ReviewSubmissionState enum

Lifecycle state of one App Store review submission.

Inheritance
Available extensions

Values

readyForReview → const ReviewSubmissionState

Items were added, but the submission has not been sent to Apple.

const ReviewSubmissionState('READY_FOR_REVIEW')
waitingForReview → const ReviewSubmissionState

Apple received the submission and has not started review.

const ReviewSubmissionState('WAITING_FOR_REVIEW')
inReview → const ReviewSubmissionState

App Review is actively reviewing the submission.

const ReviewSubmissionState('IN_REVIEW')
unresolvedIssues → const ReviewSubmissionState

One or more isSubmitted items require developer action.

const ReviewSubmissionState('UNRESOLVED_ISSUES')
canceling → const ReviewSubmissionState

Apple is processing a cancellation request.

const ReviewSubmissionState('CANCELING')
completing → const ReviewSubmissionState

Apple is moving the submission into its final state.

const ReviewSubmissionState('COMPLETING')
complete → const ReviewSubmissionState

Apple finished processing the submission.

const ReviewSubmissionState('COMPLETE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Stable App Store Connect API value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Object? value) ReviewSubmissionState
Parses the state at the App Store Connect response boundary.

Constants

values → const List<ReviewSubmissionState>
A constant List of the values in this enum, in order of their declaration.