AndroidConfig class abstract

Android project, app-bundle, and Google Play configuration.

Available extensions
Annotations
  • @freezed

Constructors

AndroidConfig({@Default.new(false) bool isEnabled, @Default.new('0.0.0') String initialVersion, String? packageName, String? buildCommand, @Default.new('build/app/outputs/bundle/release') String aabOutputPath, @Default.new(GooglePlayConfig()) GooglePlayConfig googlePlay})
Creates Android configuration.
const
factory

Properties

aabOutputPath String
no setterinherited
buildCommand String?
no setterinherited
copyWith → $AndroidConfigCopyWith<AndroidConfig>
Create a copy of AndroidConfig with the given fields replaced by the non-null parameter values.
no setterinherited
googlePlay GooglePlayConfig
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
initialVersion String
no setterinherited
isEnabled bool
no setterinherited
packageName String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AndroidConfig value)) → TResult

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AndroidConfig value)?) → TResult?

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AndroidConfig value)?, {required TResult orElse()}) → TResult

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool isEnabled, String initialVersion, String? packageName, String? buildCommand, String aabOutputPath, GooglePlayConfig googlePlay)?, {required TResult orElse()}) → TResult

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool isEnabled, String initialVersion, String? packageName, String? buildCommand, String aabOutputPath, GooglePlayConfig googlePlay)) → TResult

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool isEnabled, String initialVersion, String? packageName, String? buildCommand, String aabOutputPath, GooglePlayConfig googlePlay)?) → TResult?

Available on AndroidConfig, provided by the AndroidConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited