android library
Android app-bundle and Google Play delivery for SMF.
Classes
- AndroidBuild
- Builds and validates Android App Bundles.
- AndroidConfig
- Android project, app-bundle, and Google Play configuration.
- AndroidCredentialProvider
- Loads Google Play and Android signing credentials from environment values.
- AndroidProject
- Android project metadata used by Google Play delivery.
- AndroidPromotionOptions
- Inputs for promoting an exact Android release candidate.
- AndroidRelease
- Promotes exact tested Google Play release candidates without rebuilding.
- AndroidReleaseCandidate
- Creates and records exact Google Play release candidates.
- AndroidReleaseCandidateDependencies
- Release-candidate build operations injectable for deterministic tests.
- AndroidReleaseCandidateOptions
- Inputs for creating an Android release candidate.
- AndroidShipReleaseResultDto
- Stable machine-readable evidence produced after shipping an Android release.
- AndroidSigningCredentials
- Android upload-key signing material.
- AndroidSigningSession
- Temporary Android upload-key installation used for one release candidate build.
- GooglePlayApi
- Google Play operations required by SMF release candidate and promotion workflows.
- GooglePlayBundle
- One uploaded Android App Bundle.
- GooglePlayClient
- Authenticated implementation backed by the official Google API packages.
- GooglePlayConfig
- Google Play testing and production delivery configuration.
- GooglePlayCredentials
- Google Play service-account credentials.
- GooglePlayEdit
- One Google Play edit.
- GooglePlayRelease
- One release configured on a Google Play track.
- GooglePlayReleaseCandidateConfig
- Google Play delivery used while the release PR is open.
- GooglePlayShipConfig
- Google Play delivery performed after the release candidate is approved and merged.
- GooglePlayTrack
- Current desired state for a Google Play track.
Enums
- GooglePlayReleaseCandidateTarget
- Google Play testing destination for an Android release candidate.
- GooglePlayReleaseStatus
- State of one release returned by Google Play.
- GooglePlayShipTarget
- Google Play destination used by the ship phase.