AndroidBuild class final

Builds and validates Android App Bundles.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findArtifact(String projectRoot, {String aabOutputPath = 'build/app/outputs/bundle/release'}) Future<String>
Finds exactly one repository-contained Android App Bundle.
resolveCommand(String projectRoot, {String? configuredCommand}) Future<String>
Selects a project-owned command or the repository-aware Flutter default.
run({required String projectRoot, required String command, required String aabOutputPath, required String version, required String buildNumber, required AndroidSigningSession signing, required AndroidSigningCredentials credentials, String? flavor, ProcessRunner processRunner = const SystemProcessRunner()}) Future<String>
Builds and verifies an AAB signed by the configured upload key.