AndroidPromotionOptions class final
Inputs for promoting an exact Android release candidate.
Constructors
-
AndroidPromotionOptions({required String workingDirectory, required GooglePlayCredentials googlePlayCredentials, required GitHubContext github, String? smfPath, GooglePlayApi? client, GitHubApi? githubApi, Future<
String> resolvePackage(String appRoot, AndroidConfig config, {String? flavor}) = AndroidProject.resolvePackageName}) -
Creates Android promotion options.
const
Properties
- client → GooglePlayApi?
-
Optional Google Play client override.
final
- github → GitHubContext
-
GitHub repository and authentication context.
final
- githubApi → GitHubApi?
-
Optional GitHub API override.
final
- googlePlayCredentials → GooglePlayCredentials
-
Google Play service-account credentials.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resolvePackage
→ Future<
String> Function(String appRoot, AndroidConfig config, {String? flavor}) -
Android application-ID resolver.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smfPath → String?
-
Optional selected
smfdirectory.final - workingDirectory → String
-
Directory from which SMF discovers the target app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited