AndroidReleaseCandidateOptions class final
Inputs for creating an Android release candidate.
Constructors
- AndroidReleaseCandidateOptions({required String workingDirectory, required GooglePlayCredentials googlePlayCredentials, required AndroidSigningCredentials signingCredentials, String? smfPath, GitHubContext? github, bool shouldCommitReceipt = true, GooglePlayApi? client, AndroidReleaseCandidateDependencies dependencies = const AndroidReleaseCandidateDependencies()})
-
Creates Android release candidate options.
const
Properties
- client → GooglePlayApi?
-
Optional Google Play client override.
final
- dependencies → AndroidReleaseCandidateDependencies
-
Release-candidate operation overrides.
final
- github → GitHubContext?
-
Optional GitHub context used to push release candidate evidence.
final
- googlePlayCredentials → GooglePlayCredentials
-
Google Play service-account credentials.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldCommitReceipt → bool
-
Whether to commit and push the receipt.
final
- signingCredentials → AndroidSigningCredentials
-
Google Play upload-key credentials.
final
- smfPath → String?
-
Optional selected
smfdirectory.final - workingDirectory → String
-
Directory from which SMF discovers the target app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited