AndroidSigningCredentials class final

Android upload-key signing material.

This deliberately avoids generated value semantics so passwords and key material are never included in diagnostics.

Constructors

AndroidSigningCredentials({required String keystoreBase64, required String keyAlias, required String keystorePassword, required String keyPassword})
Creates Android upload-key credentials.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyAlias String
Alias of the upload key inside the keystore.
final
keyPassword String
Password protecting the selected upload key.
final
keystoreBase64 String
Base64-encoded JKS or PKCS12 upload keystore.
final
keystorePassword String
Password protecting the keystore.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited