AndroidSigningSession class final
Temporary Android upload-key installation used for one release candidate build.
Properties
- directory → Directory
-
Private temporary directory containing generated signing inputs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keystorePath → String
-
Temporary upload-keystore path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanup(
) → Future< void> - Removes every signing file created by SMF.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
install(
AndroidSigningCredentials credentials, {ProcessRunner processRunner = const SystemProcessRunner()}) → Future< AndroidSigningSession> - Installs upload-key material without changing the consumer repository.