Google Play operations required by SMF release candidate and promotion workflows.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Releases authentication and transport resources.
-
commitEdit(
{required String packageName, required String editId, required bool areChangesNotSentForReview}) → Future< void> - Commits an edit without canceling an already-running Play review.
-
createEdit(
String packageName) → Future< GooglePlayEdit> - Starts an isolated application edit.
-
deleteEdit(
{required String packageName, required String editId}) → Future< void> - Deletes an uncommitted edit.
-
getTrack(
{required String packageName, required String editId, required String track}) → Future< GooglePlayTrack> - Reads a track inside an edit.
-
listArtifactVersionCodes(
{required String packageName, required String editId}) → Future< Set< int> > - Lists every APK and AAB version code visible inside an edit.
-
listBundles(
{required String packageName, required String editId}) → Future< List< GooglePlayBundle> > - Lists app bundles visible inside an edit.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateTrack(
{required String packageName, required String editId, required GooglePlayTrack track}) → Future< GooglePlayTrack> - Replaces the desired releases on a track inside an edit.
-
uploadBundle(
{required String packageName, required String editId, required String aabPath}) → Future< GooglePlayBundle> - Uploads an AAB to an edit.
-
validateEdit(
{required String packageName, required String editId}) → Future< void> - Validates all changes in an edit without committing them.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited