AppStoreConnectClient class final
Authenticated App Store Connect implementation used by SMF.
- Implemented types
Constructors
-
AppStoreConnectClient(AppleCredentials credentials, {Client? httpClient, Future<
String> tokenProvider()?, Uri? baseUrl, DateTime currentTime()?, Future<void> delay(Duration)?}) - Creates an App Store Connect client.
Properties
- baseUrl → Uri
-
final
- credentials → AppleCredentials
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBuildToGroups(
{required String appId, required String buildId, required List< String> names, required bool isInternal}) → Future<void> -
Adds an exact build to the named internal or external TestFlight groups.
override
-
appStoreVersionBuildId(
String appStoreVersionId) → Future< String?> -
Returns the build currently attached to an App Store version.
override
-
attachBuildToVersion(
{required String appStoreVersionId, required String buildId}) → Future< void> -
Attaches an exact build to an App Store version.
override
-
buildsForVersion(
{required String appId, required String version}) → Future< List< ApiResourceDto< >BuildAttributesDto> > -
Lists builds uploaded for one app marketing version.
override
-
close(
) → void -
Releases authentication and transport resources.
override
-
createAppStoreProfile(
{required String name, required String bundleIdId, required String certificateId}) → Future< AppleProvisioningProfileDto> -
Creates an App Store profile for one bundle identifier and certificate.
override
-
findApp(
String bundleId) → Future< ApiResourceDto< AppAttributesDto> > -
Finds the app whose bundle identifier exactly matches
bundleId.override -
findOrCreateAppStoreVersion(
{required String appId, required String version, required bool shouldReleaseAutomatically}) → Future< ApiResourceDto< AppStoreVersionAttributesDto> > -
Finds or creates the editable App Store version for a marketing version.
override
-
listAppStoreProfiles(
) → Future< List< AppleProvisioningProfileDto> > -
Lists App Store provisioning profiles registered with the developer team.
override
-
listBuildsForPrereleaseVersion(
String prereleaseVersionId) → Future< List< ApiResourceDto< >BuildAttributesDto> > -
listIosBundleIds(
) → Future< List< AppleBundleIdentifierDto> > -
Lists iOS bundle identifiers registered with the developer team.
override
-
listPrereleaseVersions(
String appId, {String? version}) → Future< List< ApiResourceDto< >PrereleaseVersionAttributesDto> > -
listSigningCertificates(
) → Future< List< AppleSigningCertificateDto> > -
Lists signing certificates registered with the developer team.
override
-
nextBuildNumber(
{required String appId, required String version}) → Future< String> -
Returns the next unused build number for one app marketing version.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAppStoreReleaseNotes(
{required String appStoreVersionId, required String locale, required String whatsNew}) → Future< void> -
Creates or updates localized App Store "What's New" text.
override
-
setBetaBuildLocalization(
{required String buildId, required String locale, required String whatsNew}) → Future< void> -
Creates or updates localized TestFlight "What to Test" text.
override
-
submitBuildForBetaReview(
String buildId) → Future< String> -
Submits an exact build for TestFlight beta review.
override
-
submitVersionForReview(
{required String appId, required String appStoreVersionId}) → Future< String> -
Creates or reuses the review submission for an App Store version.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForBuild(
{required String appId, required String version, required String buildNumber, required int timeoutMinutes, Duration interval = const Duration(seconds: 30)}) → Future< ApiResourceDto< BuildAttributesDto> > -
Waits for an exact uploaded build to finish App Store processing.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited