ApplePromotionOptions class final
Inputs and injectable adapters for promoting an iOS release candidate.
Constructors
-
ApplePromotionOptions({required String workingDirectory, required AppleCredentials appleCredentials, required GitHubContext github, String? smfPath, AppStoreConnectApi? client, GitHubApi? githubApi, Future<
String> resolveBundleIdentifier(String appRoot, IosConfig config, {String? flavor}) = AppleProject.resolveBundleId}) -
Creates promotion options.
const
Properties
- appleCredentials → AppleCredentials
-
App Store Connect credentials.
final
- client → AppStoreConnectApi?
-
Optional App Store Connect client override.
final
- github → GitHubContext
-
GitHub repository and authentication context.
final
- githubApi → GitHubApi?
-
Optional GitHub client override.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resolveBundleIdentifier
→ Future<
String> Function(String appRoot, IosConfig config, {String? flavor}) -
Xcode bundle-identifier resolver.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smfPath → String?
-
Optional explicit
smfdirectory, relative to workingDirectory.final - workingDirectory → String
-
Directory from which SMF discovers the target app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited