AppleProvisioningProfileDto class abstract
An App Store Connect provisioning profile and its signing relationships.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
AppleProvisioningProfileDto({required String id, required String name, required String profileType, required String profileState, required String profileContent, required String uuid, required DateTime createdDate, required DateTime expirationDate, required String bundleIdId, required List<
String> certificateIds}) -
Creates an Apple provisioning-profile resource.
constfactory
Properties
- bundleIdId → String
-
no setterinherited
-
certificateIds
→ List<
String> -
no setterinherited
-
copyWith
→ $AppleProvisioningProfileDtoCopyWith<
AppleProvisioningProfileDto> -
Create a copy of AppleProvisioningProfileDto
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdDate → DateTime
-
no setterinherited
- expirationDate → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- name → String
-
no setterinherited
- profileContent → String
-
no setterinherited
- profileState → String
-
no setterinherited
- profileType → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AppleProvisioningProfileDto value)) → TResult -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AppleProvisioningProfileDto value)?) → TResult? -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AppleProvisioningProfileDto value)?, {required TResult orElse()}) → TResult -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List< String> certificateIds)?, {required TResult orElse()}) → TResult -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List< String> certificateIds)) → TResult -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String name, String profileType, String profileState, String profileContent, String uuid, DateTime createdDate, DateTime expirationDate, String bundleIdId, List< String> certificateIds)?) → TResult? -
Available on AppleProvisioningProfileDto, provided by the AppleProvisioningProfileDtoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited