AppleReleaseCandidateOptions class final
Inputs and injectable adapters for creating an iOS release candidate.
Constructors
- AppleReleaseCandidateOptions({required String workingDirectory, required AppleCredentials appleCredentials, required AppleSigningCredentials signingCredentials, String? smfPath, GitHubContext? github, bool shouldCommitReceipt = true, AppStoreConnectApi? client, AppleReleaseCandidateDependencies dependencies = const AppleReleaseCandidateDependencies()})
-
Creates release candidate options.
const
Properties
- appleCredentials → AppleCredentials
-
App Store Connect credentials.
final
- client → AppStoreConnectApi?
-
Optional App Store Connect client override.
final
- dependencies → AppleReleaseCandidateDependencies
-
Release-candidate build operation overrides.
final
- github → GitHubContext?
-
Optional GitHub context used to commit release candidate evidence.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldCommitReceipt → bool
-
Whether release candidate evidence should be committed to the release branch.
final
- signingCredentials → AppleSigningCredentials
-
Distribution signing credentials.
final
- smfPath → String?
-
Optional explicit
smfdirectory, relative to workingDirectory.final - workingDirectory → String
-
Directory from which SMF discovers the target app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited