AppleResolvedSigningAssets class final
Signing material after SMF has resolved every signed Apple target.
This deliberately avoids generated value semantics so signing secrets are
never included in a generated toString.
Constructors
-
AppleResolvedSigningAssets({required AppleSigningCredentials credentials, required Map<
String, String> profilesByBundleId}) - Creates resolved signing material.
Properties
- credentials → AppleSigningCredentials
-
Distribution certificate and its password.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
profilesByBundleId
→ Map<
String, String> -
Apple-managed signing data keyed by exact bundle identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited