AppleShipReleaseResultDto class abstract
Stable machine-readable evidence produced after shipping an Apple release.
- Annotations
-
- @freezed
Constructors
- AppleShipReleaseResultDto({required String version, required String tag, required String artifactId, required String buildNumber, required String githubReleaseUrl, @Default.new(ReleasePlatform.ios) ReleasePlatform platform, String? appStoreVersionId, String? reviewSubmissionId, String? betaReviewSubmissionId})
-
Creates an Apple ship result.
constfactory
-
AppleShipReleaseResultDto.fromJson(Map<
String, Object?> json) -
Decodes Apple ship evidence from JSON.
factory
Properties
- appStoreVersionId → String?
-
no setterinherited
- artifactId → String
-
no setterinherited
- betaReviewSubmissionId → String?
-
no setterinherited
- buildNumber → String
-
no setterinherited
-
copyWith
→ $AppleShipReleaseResultDtoCopyWith<
AppleShipReleaseResultDto> -
Create a copy of AppleShipReleaseResultDto
with the given fields replaced by the non-null parameter values.
no setterinherited
- githubReleaseUrl → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → ReleasePlatform
-
no setterinherited
- reviewSubmissionId → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
no setterinherited
- version → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AppleShipReleaseResultDto to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited