GitHubApi class abstract interface

GitHub operations required by SMF release workflows.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLabels({required int issueNumber, required List<String> labels}) Future<void>
Adds labels to one issue or pull request.
createLabel({required String name, required String color}) Future<void>
Creates a repository label.
createPullRequest({required String head, required String base, required String title, required String body}) Future<GitHubPullRequestDto>
Creates a pull request.
createRelease({required String tag, required String name, required String body, required String targetCommitish}) Future<GitHubReleaseDto>
Creates a GitHub Release for an existing tag target.
labelExists(String name) Future<bool>
Whether a repository label named name exists.
listPullRequests({required String state, required String head, required String base, required int perPage}) Future<List<GitHubPullRequestDto>>
Lists pull requests matching an exact state, head, and base branch.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseByTag(String tag) Future<GitHubReleaseDto?>
Finds the GitHub Release attached to tag, if one exists.
toString() String
A string representation of this object.
inherited
updatePullRequest({required int number, required String title, required String body}) Future<void>
Replaces the title and body of an existing pull request.

Operators

operator ==(Object other) bool
The equality operator.
inherited